@@ -1,6 +1,7 @@
-from .rustplus_pb2 import *
+from .rustplus_proto import *
 from .rustws import RustWebsocket
 from .token_bucket import RateLimiter
 from .rust_remote_interface import RustRemote
 from .heartbeat import HeartBeat
 from .event_handler import EventHandler
+from .map_event_listener import MapEventListener
