@@ -19,13 +19,13 @@ def deprecated(reason):
 
         @functools.wraps(func1)
         def new_func1(*args, **kwargs):
-            warnings.simplefilter('always', DeprecationWarning)
+            warnings.simplefilter("always", DeprecationWarning)
             warnings.warn(
                 fmt1.format(name=func1.__name__, reason=reason),
                 category=DeprecationWarning,
-                stacklevel=2
+                stacklevel=2,
             )
-            warnings.simplefilter('default', DeprecationWarning)
+            warnings.simplefilter("default", DeprecationWarning)
             return func1(*args, **kwargs)
 
         return new_func1
